import Vue from 'vue';
import Router from 'vue-router';
import { AuthGuard } from '@/utils';
import qs from 'qs';
import { globalRoutes, indexRoutes} from '@/router'
import { AppService } from '@/studio-core/service/app-service/AppService';

Vue.use(Router);

const appService = new AppService();

const router = new Router({
    routes: [
        {
            path: '/appindexview/:appindexview?',
            beforeEnter: async (to: any, from: any, next: any) => {
                const routerParamsName = 'appindexview';
                const params: any = {};
                if (to.params && to.params[routerParamsName]) {
                    params[routerParamsName] = to.params[routerParamsName];
                }
                const url: string = '/appdata';
                await AuthGuard.getInstance().authGuard(url, params, router);
                appService.navHistory.indexMeta = {
                    caption: 'app.views.appindexview.title',
                    info:'',
                    viewType: 'APPINDEX',
                    parameters: [
                        { pathName: 'appindexview', parameterName: 'appindexview' },
                    ],
                    requireAuth: true,
                };
                next();
            },
            meta: {  
                caption: 'app.views.appindexview.title',
                info:'',
                viewType: 'APPINDEX',
                parameters: [
                    { pathName: 'appindexview', parameterName: 'appindexview' },
                ],
                requireAuth: true,
            },
            component: () => import('@pages/base/app-index-view/app-index-view.vue'),
            children: [
                {
                    path: 'eamsparepartsgroups/:eamsparepartsgroup?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamsparepartsgroup.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamsparepartsgroups', parameterName: 'eamsparepartsgroup' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamspare-parts-group-grid-view/eamspare-parts-group-grid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamapplies/:eamapply?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamapply.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-info-main-view/eamapply-info-main-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamapplies/:eamapply?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamapply.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-info-main-view/eamapply-info-main-view.vue'),
                },
                {
                    path: 'eamapplies/:eamapply?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamapply.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-info-main-view/eamapply-info-main-view.vue'),
                },
                {
                    path: 'eamassetstatemodellines/:eamassetstatemodelline?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamassetstatemodelline.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassetstatemodellines', parameterName: 'eamassetstatemodelline' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-state-model-line-edit-view/eamasset-state-model-line-edit-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.eamasset.views.treeexpview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-tree-exp-view/eamasset-tree-exp-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.eamasset.views.treeexpview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-tree-exp-view/eamasset-tree-exp-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamapplies/:eamapply?/assetapplygridview/:assetapplygridview?',
                    meta: {
                        caption: 'entities.eamapply.views.assetapplygridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'assetapplygridview', parameterName: 'assetapplygridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-asset-apply-grid-view/eamapply-asset-apply-grid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamapplies/:eamapply?/assetapplygridview/:assetapplygridview?',
                    meta: {
                        caption: 'entities.eamapply.views.assetapplygridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'assetapplygridview', parameterName: 'assetapplygridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-asset-apply-grid-view/eamapply-asset-apply-grid-view.vue'),
                },
                {
                    path: 'eamapplies/:eamapply?/assetapplygridview/:assetapplygridview?',
                    meta: {
                        caption: 'entities.eamapply.views.assetapplygridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'assetapplygridview', parameterName: 'assetapplygridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-asset-apply-grid-view/eamapply-asset-apply-grid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.eamlocation.views.treeexpview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-tree-exp-view/eamlocation-tree-exp-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/quickcreateview/:quickcreateview?',
                    meta: {
                        caption: 'entities.eamlocation.views.quickcreateview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'quickcreateview', parameterName: 'quickcreateview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-quick-create-view/eamlocation-quick-create-view.vue'),
                },
                {
                    path: 'eamservicelevels/:eamservicelevel?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamservicelevel.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamservicelevels', parameterName: 'eamservicelevel' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamservice-level-grid-view/eamservice-level-grid-view.vue'),
                },
                {
                    path: 'eamsparepartsgroups/:eamsparepartsgroup?/eamsparepartspros/:eamsparepartspro?/partsprogridview/:partsprogridview?',
                    meta: {
                        caption: 'entities.eamsparepartspro.views.partsprogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamsparepartsgroups', parameterName: 'eamsparepartsgroup' },
                            { pathName: 'eamsparepartspros', parameterName: 'eamsparepartspro' },
                            { pathName: 'partsprogridview', parameterName: 'partsprogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamspare-parts-proparts-pro-grid-view/eamspare-parts-proparts-pro-grid-view.vue'),
                },
                {
                    path: 'eamsparepartspros/:eamsparepartspro?/partsprogridview/:partsprogridview?',
                    meta: {
                        caption: 'entities.eamsparepartspro.views.partsprogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamsparepartspros', parameterName: 'eamsparepartspro' },
                            { pathName: 'partsprogridview', parameterName: 'partsprogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamspare-parts-proparts-pro-grid-view/eamspare-parts-proparts-pro-grid-view.vue'),
                },
                {
                    path: 'eamlocationstatemodels/:eamlocationstatemodel?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.eamlocationstatemodel.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocationstatemodels', parameterName: 'eamlocationstatemodel' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-state-model-pickup-grid-view/eamlocation-state-model-pickup-grid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamplans/:eamplan?/eamplanlines/:eamplanline?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamplanline.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamplanlines', parameterName: 'eamplanline' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-line-edit-view/eamplan-line-edit-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamplans/:eamplan?/eamplanlines/:eamplanline?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamplanline.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamplanlines', parameterName: 'eamplanline' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-line-edit-view/eamplan-line-edit-view.vue'),
                },
                {
                    path: 'eamplans/:eamplan?/eamplanlines/:eamplanline?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamplanline.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamplanlines', parameterName: 'eamplanline' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-line-edit-view/eamplan-line-edit-view.vue'),
                },
                {
                    path: 'eamplanlines/:eamplanline?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamplanline.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplanlines', parameterName: 'eamplanline' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-line-edit-view/eamplan-line-edit-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.eamlocation.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-pickup-view/eamlocation-pickup-view.vue'),
                },
                {
                    path: 'eamlocationstatemodels/:eamlocationstatemodel?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.eamlocationstatemodel.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocationstatemodels', parameterName: 'eamlocationstatemodel' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-state-model-pickup-view/eamlocation-state-model-pickup-view.vue'),
                },
                {
                    path: 'eamlocationstates/:eamlocationstate?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.eamlocationstate.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocationstates', parameterName: 'eamlocationstate' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-state-pickup-view/eamlocation-state-pickup-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamlocation.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-info-main-view/eamlocation-info-main-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamplans/:eamplan?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamplan.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-info-main-view/eamplan-info-main-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamplans/:eamplan?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamplan.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-info-main-view/eamplan-info-main-view.vue'),
                },
                {
                    path: 'eamplans/:eamplan?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamplan.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-info-main-view/eamplan-info-main-view.vue'),
                },
                {
                    path: 'eamassettypes/:eamassettype?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamassettype.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassettypes', parameterName: 'eamassettype' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-type-info-main-view/eamasset-type-info-main-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamapplies/:eamapply?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamapply.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-grid-view/eamapply-grid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamapplies/:eamapply?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamapply.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-grid-view/eamapply-grid-view.vue'),
                },
                {
                    path: 'eamapplies/:eamapply?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamapply.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-grid-view/eamapply-grid-view.vue'),
                },
                {
                    path: 'eamlocationtypes/:eamlocationtype?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.eamlocationtype.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocationtypes', parameterName: 'eamlocationtype' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-type-pickup-view/eamlocation-type-pickup-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamasset.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-info-main-view/eamasset-info-main-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamasset.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-info-main-view/eamasset-info-main-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamasset.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-edit-view/eamasset-edit-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamasset.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-edit-view/eamasset-edit-view.vue'),
                },
                {
                    path: 'eamassettypes/:eamassettype?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamassettype.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassettypes', parameterName: 'eamassettype' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-type-grid-view/eamasset-type-grid-view.vue'),
                },
                {
                    path: 'eamassetstatemodels/:eamassetstatemodel?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.eamassetstatemodel.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassetstatemodels', parameterName: 'eamassetstatemodel' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-state-model-pickup-grid-view/eamasset-state-model-pickup-grid-view.vue'),
                },
                {
                    path: 'eamdocumenttypes/:eamdocumenttype?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamdocumenttype.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamdocumenttypes', parameterName: 'eamdocumenttype' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamdocument-type-edit-view/eamdocument-type-edit-view.vue'),
                },
                {
                    path: 'eamservicelevels/:eamservicelevel?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamservicelevel.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamservicelevels', parameterName: 'eamservicelevel' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamservice-level-edit-view/eamservice-level-edit-view.vue'),
                },
                {
                    path: 'eamsparepartsgroups/:eamsparepartsgroup?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamsparepartsgroup.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamsparepartsgroups', parameterName: 'eamsparepartsgroup' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamspare-parts-group-info-view/eamspare-parts-group-info-view.vue'),
                },
                {
                    path: 'eamapplytypes/:eamapplytype?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.eamapplytype.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamapplytypes', parameterName: 'eamapplytype' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-type-pickup-grid-view/eamapply-type-pickup-grid-view.vue'),
                },
                {
                    path: 'eamsparepartsgroups/:eamsparepartsgroup?/eamassetpartsgroups/:eamassetpartsgroup?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamassetpartsgroup.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamsparepartsgroups', parameterName: 'eamsparepartsgroup' },
                            { pathName: 'eamassetpartsgroups', parameterName: 'eamassetpartsgroup' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-parts-group-edit-view/eamasset-parts-group-edit-view.vue'),
                },
                {
                    path: 'eamassettypes/:eamassettype?/eamassetpartsgroups/:eamassetpartsgroup?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamassetpartsgroup.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassettypes', parameterName: 'eamassettype' },
                            { pathName: 'eamassetpartsgroups', parameterName: 'eamassetpartsgroup' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-parts-group-edit-view/eamasset-parts-group-edit-view.vue'),
                },
                {
                    path: 'eamassetpartsgroups/:eamassetpartsgroup?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamassetpartsgroup.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassetpartsgroups', parameterName: 'eamassetpartsgroup' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-parts-group-edit-view/eamasset-parts-group-edit-view.vue'),
                },
                {
                    path: 'eammonitorpoints/:eammonitorpoint?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.eammonitorpoint.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eammonitorpoints', parameterName: 'eammonitorpoint' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eammonitor-point-pickup-grid-view/eammonitor-point-pickup-grid-view.vue'),
                },
                {
                    path: 'eamlocationtypes/:eamlocationtype?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.eamlocationtype.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocationtypes', parameterName: 'eamlocationtype' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-type-pickup-grid-view/eamlocation-type-pickup-grid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamplans/:eamplan?/eamworkorders/:eamworkorder?/summaryview/:summaryview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.summaryview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'summaryview', parameterName: 'summaryview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-summary-view/eamwork-order-summary-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamapplies/:eamapply?/eamworkorders/:eamworkorder?/summaryview/:summaryview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.summaryview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'summaryview', parameterName: 'summaryview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-summary-view/eamwork-order-summary-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamplans/:eamplan?/eamworkorders/:eamworkorder?/summaryview/:summaryview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.summaryview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'summaryview', parameterName: 'summaryview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-summary-view/eamwork-order-summary-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamworkorders/:eamworkorder?/summaryview/:summaryview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.summaryview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'summaryview', parameterName: 'summaryview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-summary-view/eamwork-order-summary-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamapplies/:eamapply?/eamworkorders/:eamworkorder?/summaryview/:summaryview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.summaryview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'summaryview', parameterName: 'summaryview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-summary-view/eamwork-order-summary-view.vue'),
                },
                {
                    path: 'eamplans/:eamplan?/eamworkorders/:eamworkorder?/summaryview/:summaryview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.summaryview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'summaryview', parameterName: 'summaryview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-summary-view/eamwork-order-summary-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamworkorders/:eamworkorder?/summaryview/:summaryview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.summaryview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'summaryview', parameterName: 'summaryview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-summary-view/eamwork-order-summary-view.vue'),
                },
                {
                    path: 'eamapplies/:eamapply?/eamworkorders/:eamworkorder?/summaryview/:summaryview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.summaryview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'summaryview', parameterName: 'summaryview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-summary-view/eamwork-order-summary-view.vue'),
                },
                {
                    path: 'eamworkorders/:eamworkorder?/summaryview/:summaryview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.summaryview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'summaryview', parameterName: 'summaryview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-summary-view/eamwork-order-summary-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/summaryview/:summaryview?',
                    meta: {
                        caption: 'entities.eamasset.views.summaryview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'summaryview', parameterName: 'summaryview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-summary-view/eamasset-summary-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/summaryview/:summaryview?',
                    meta: {
                        caption: 'entities.eamasset.views.summaryview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'summaryview', parameterName: 'summaryview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-summary-view/eamasset-summary-view.vue'),
                },
                {
                    path: 'eamassetstatemodellines/:eamassetstatemodelline?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamassetstatemodelline.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassetstatemodellines', parameterName: 'eamassetstatemodelline' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-state-model-line-grid-view/eamasset-state-model-line-grid-view.vue'),
                },
                {
                    path: 'eamlocationtypes/:eamlocationtype?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamlocationtype.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocationtypes', parameterName: 'eamlocationtype' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-type-grid-view/eamlocation-type-grid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamasset.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-info-view/eamasset-info-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamasset.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-info-view/eamasset-info-view.vue'),
                },
                {
                    path: 'eamassetstatemodels/:eamassetstatemodel?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamassetstatemodel.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassetstatemodels', parameterName: 'eamassetstatemodel' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-state-model-edit-view/eamasset-state-model-edit-view.vue'),
                },
                {
                    path: 'eamassetstates/:eamassetstate?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.eamassetstate.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassetstates', parameterName: 'eamassetstate' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-state-pickup-grid-view/eamasset-state-pickup-grid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamplans/:eamplan?/eamworkorders/:eamworkorder?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-info-view/eamwork-order-info-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamapplies/:eamapply?/eamworkorders/:eamworkorder?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-info-view/eamwork-order-info-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamplans/:eamplan?/eamworkorders/:eamworkorder?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-info-view/eamwork-order-info-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamworkorders/:eamworkorder?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-info-view/eamwork-order-info-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamapplies/:eamapply?/eamworkorders/:eamworkorder?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-info-view/eamwork-order-info-view.vue'),
                },
                {
                    path: 'eamplans/:eamplan?/eamworkorders/:eamworkorder?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-info-view/eamwork-order-info-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamworkorders/:eamworkorder?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-info-view/eamwork-order-info-view.vue'),
                },
                {
                    path: 'eamapplies/:eamapply?/eamworkorders/:eamworkorder?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-info-view/eamwork-order-info-view.vue'),
                },
                {
                    path: 'eamworkorders/:eamworkorder?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-info-view/eamwork-order-info-view.vue'),
                },
                {
                    path: 'eamwotypes/:eamwotype?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.eamwotype.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamwotypes', parameterName: 'eamwotype' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwotype-pickup-view/eamwotype-pickup-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamapplies/:eamapply?/quickcreateview/:quickcreateview?',
                    meta: {
                        caption: 'entities.eamapply.views.quickcreateview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'quickcreateview', parameterName: 'quickcreateview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-quick-create-view/eamapply-quick-create-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamapplies/:eamapply?/quickcreateview/:quickcreateview?',
                    meta: {
                        caption: 'entities.eamapply.views.quickcreateview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'quickcreateview', parameterName: 'quickcreateview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-quick-create-view/eamapply-quick-create-view.vue'),
                },
                {
                    path: 'eamapplies/:eamapply?/quickcreateview/:quickcreateview?',
                    meta: {
                        caption: 'entities.eamapply.views.quickcreateview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'quickcreateview', parameterName: 'quickcreateview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-quick-create-view/eamapply-quick-create-view.vue'),
                },
                {
                    path: 'eamsparepartsgroups/:eamsparepartsgroup?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.eamsparepartsgroup.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamsparepartsgroups', parameterName: 'eamsparepartsgroup' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamspare-parts-group-pickup-grid-view/eamspare-parts-group-pickup-grid-view.vue'),
                },
                {
                    path: 'eamassettypes/:eamassettype?/eamdocuments/:eamdocument?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamdocument.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassettypes', parameterName: 'eamassettype' },
                            { pathName: 'eamdocuments', parameterName: 'eamdocument' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamdocument-grid-view/eamdocument-grid-view.vue'),
                },
                {
                    path: 'eamdocuments/:eamdocument?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamdocument.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamdocuments', parameterName: 'eamdocument' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamdocument-grid-view/eamdocument-grid-view.vue'),
                },
                {
                    path: 'eamwotypes/:eamwotype?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamwotype.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamwotypes', parameterName: 'eamwotype' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwotype-edit-view/eamwotype-edit-view.vue'),
                },
                {
                    path: 'eamdocumenttypes/:eamdocumenttype?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.eamdocumenttype.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamdocumenttypes', parameterName: 'eamdocumenttype' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamdocument-type-pickup-grid-view/eamdocument-type-pickup-grid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamplans/:eamplan?/eamworkorders/:eamworkorder?/applywogridview/:applywogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.applywogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'applywogridview', parameterName: 'applywogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-apply-wogrid-view/eamwork-order-apply-wogrid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamapplies/:eamapply?/eamworkorders/:eamworkorder?/applywogridview/:applywogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.applywogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'applywogridview', parameterName: 'applywogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-apply-wogrid-view/eamwork-order-apply-wogrid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamplans/:eamplan?/eamworkorders/:eamworkorder?/applywogridview/:applywogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.applywogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'applywogridview', parameterName: 'applywogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-apply-wogrid-view/eamwork-order-apply-wogrid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamworkorders/:eamworkorder?/applywogridview/:applywogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.applywogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'applywogridview', parameterName: 'applywogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-apply-wogrid-view/eamwork-order-apply-wogrid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamapplies/:eamapply?/eamworkorders/:eamworkorder?/applywogridview/:applywogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.applywogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'applywogridview', parameterName: 'applywogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-apply-wogrid-view/eamwork-order-apply-wogrid-view.vue'),
                },
                {
                    path: 'eamplans/:eamplan?/eamworkorders/:eamworkorder?/applywogridview/:applywogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.applywogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'applywogridview', parameterName: 'applywogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-apply-wogrid-view/eamwork-order-apply-wogrid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamworkorders/:eamworkorder?/applywogridview/:applywogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.applywogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'applywogridview', parameterName: 'applywogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-apply-wogrid-view/eamwork-order-apply-wogrid-view.vue'),
                },
                {
                    path: 'eamapplies/:eamapply?/eamworkorders/:eamworkorder?/applywogridview/:applywogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.applywogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'applywogridview', parameterName: 'applywogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-apply-wogrid-view/eamwork-order-apply-wogrid-view.vue'),
                },
                {
                    path: 'eamworkorders/:eamworkorder?/applywogridview/:applywogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.applywogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'applywogridview', parameterName: 'applywogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-apply-wogrid-view/eamwork-order-apply-wogrid-view.vue'),
                },
                {
                    path: 'eamassettypes/:eamassettype?/eamdocuments/:eamdocument?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamdocument.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassettypes', parameterName: 'eamassettype' },
                            { pathName: 'eamdocuments', parameterName: 'eamdocument' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamdocument-edit-view/eamdocument-edit-view.vue'),
                },
                {
                    path: 'eamdocuments/:eamdocument?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamdocument.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamdocuments', parameterName: 'eamdocument' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamdocument-edit-view/eamdocument-edit-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/childgridview/:childgridview?',
                    meta: {
                        caption: 'entities.eamlocation.views.childgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'childgridview', parameterName: 'childgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-child-grid-view/eamlocation-child-grid-view.vue'),
                },
                {
                    path: 'eamproducts/:eamproduct?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.eamproduct.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamproducts', parameterName: 'eamproduct' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamproductpickup-grid-view/eamproductpickup-grid-view.vue'),
                },
                {
                    path: 'eamlocationstatemodellines/:eamlocationstatemodelline?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamlocationstatemodelline.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocationstatemodellines', parameterName: 'eamlocationstatemodelline' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-state-model-line-grid-view/eamlocation-state-model-line-grid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamplans/:eamplan?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.eamplan.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-pickup-view/eamplan-pickup-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamplans/:eamplan?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.eamplan.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-pickup-view/eamplan-pickup-view.vue'),
                },
                {
                    path: 'eamplans/:eamplan?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.eamplan.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-pickup-view/eamplan-pickup-view.vue'),
                },
                {
                    path: 'eamwotypes/:eamwotype?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.eamwotype.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamwotypes', parameterName: 'eamwotype' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwotype-pickup-grid-view/eamwotype-pickup-grid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.eamlocation.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-pickup-grid-view/eamlocation-pickup-grid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamplans/:eamplan?/eamplanlines/:eamplanline?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamplanline.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamplanlines', parameterName: 'eamplanline' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-line-grid-view/eamplan-line-grid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamplans/:eamplan?/eamplanlines/:eamplanline?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamplanline.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamplanlines', parameterName: 'eamplanline' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-line-grid-view/eamplan-line-grid-view.vue'),
                },
                {
                    path: 'eamplans/:eamplan?/eamplanlines/:eamplanline?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamplanline.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamplanlines', parameterName: 'eamplanline' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-line-grid-view/eamplan-line-grid-view.vue'),
                },
                {
                    path: 'eamplanlines/:eamplanline?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamplanline.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplanlines', parameterName: 'eamplanline' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-line-grid-view/eamplan-line-grid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamlocation.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-grid-view/eamlocation-grid-view.vue'),
                },
                {
                    path: 'eamlocationstatemodels/:eamlocationstatemodel?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamlocationstatemodel.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocationstatemodels', parameterName: 'eamlocationstatemodel' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-state-model-grid-view/eamlocation-state-model-grid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamapplies/:eamapply?/summaryview/:summaryview?',
                    meta: {
                        caption: 'entities.eamapply.views.summaryview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'summaryview', parameterName: 'summaryview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-summary-view/eamapply-summary-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamapplies/:eamapply?/summaryview/:summaryview?',
                    meta: {
                        caption: 'entities.eamapply.views.summaryview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'summaryview', parameterName: 'summaryview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-summary-view/eamapply-summary-view.vue'),
                },
                {
                    path: 'eamapplies/:eamapply?/summaryview/:summaryview?',
                    meta: {
                        caption: 'entities.eamapply.views.summaryview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'summaryview', parameterName: 'summaryview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-summary-view/eamapply-summary-view.vue'),
                },
                {
                    path: 'eamassettypes/:eamassettype?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.eamassettype.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassettypes', parameterName: 'eamassettype' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-type-pickup-grid-view/eamasset-type-pickup-grid-view.vue'),
                },
                {
                    path: 'eamassettypes/:eamassettype?/summaryview/:summaryview?',
                    meta: {
                        caption: 'entities.eamassettype.views.summaryview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassettypes', parameterName: 'eamassettype' },
                            { pathName: 'summaryview', parameterName: 'summaryview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-type-summary-view/eamasset-type-summary-view.vue'),
                },
                {
                    path: 'eamassettypes/:eamassettype?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.eamassettype.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassettypes', parameterName: 'eamassettype' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-type-pickup-view/eamasset-type-pickup-view.vue'),
                },
                {
                    path: 'eamproducts/:eamproduct?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.eamproduct.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamproducts', parameterName: 'eamproduct' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamproductpickup-view/eamproductpickup-view.vue'),
                },
                {
                    path: 'eamapplytypes/:eamapplytype?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamapplytype.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamapplytypes', parameterName: 'eamapplytype' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-type-edit-view/eamapply-type-edit-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/childgridview/:childgridview?',
                    meta: {
                        caption: 'entities.eamasset.views.childgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'childgridview', parameterName: 'childgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-child-grid-view/eamasset-child-grid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/childgridview/:childgridview?',
                    meta: {
                        caption: 'entities.eamasset.views.childgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'childgridview', parameterName: 'childgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-child-grid-view/eamasset-child-grid-view.vue'),
                },
                {
                    path: 'eamsparepartsgroups/:eamsparepartsgroup?/dashboardview/:dashboardview?',
                    meta: {
                        caption: 'entities.eamsparepartsgroup.views.dashboardview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamsparepartsgroups', parameterName: 'eamsparepartsgroup' },
                            { pathName: 'dashboardview', parameterName: 'dashboardview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamspare-parts-group-dashboard-view/eamspare-parts-group-dashboard-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamlocation.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-edit-view/eamlocation-edit-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamplans/:eamplan?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamplan.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-info-view/eamplan-info-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamplans/:eamplan?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamplan.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-info-view/eamplan-info-view.vue'),
                },
                {
                    path: 'eamplans/:eamplan?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamplan.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-info-view/eamplan-info-view.vue'),
                },
                {
                    path: 'eamassetstates/:eamassetstate?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamassetstate.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassetstates', parameterName: 'eamassetstate' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-state-edit-view/eamasset-state-edit-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/treechildgridview/:treechildgridview?',
                    meta: {
                        caption: 'entities.eamlocation.views.treechildgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'treechildgridview', parameterName: 'treechildgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-tree-child-grid-view/eamlocation-tree-child-grid-view.vue'),
                },
                {
                    path: 'eamdocumenttypes/:eamdocumenttype?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamdocumenttype.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamdocumenttypes', parameterName: 'eamdocumenttype' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamdocument-type-grid-view/eamdocument-type-grid-view.vue'),
                },
                {
                    path: 'eamlocationstates/:eamlocationstate?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.eamlocationstate.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocationstates', parameterName: 'eamlocationstate' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-state-pickup-grid-view/eamlocation-state-pickup-grid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamplans/:eamplan?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamplan.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-grid-view/eamplan-grid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamplans/:eamplan?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamplan.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-grid-view/eamplan-grid-view.vue'),
                },
                {
                    path: 'eamplans/:eamplan?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamplan.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-grid-view/eamplan-grid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamplans/:eamplan?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.eamplan.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-pickup-grid-view/eamplan-pickup-grid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamplans/:eamplan?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.eamplan.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-pickup-grid-view/eamplan-pickup-grid-view.vue'),
                },
                {
                    path: 'eamplans/:eamplan?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.eamplan.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-pickup-grid-view/eamplan-pickup-grid-view.vue'),
                },
                {
                    path: 'eamassettypes/:eamassettype?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamassettype.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassettypes', parameterName: 'eamassettype' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-type-info-view/eamasset-type-info-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamapplies/:eamapply?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamapply.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-info-view/eamapply-info-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamapplies/:eamapply?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamapply.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-info-view/eamapply-info-view.vue'),
                },
                {
                    path: 'eamapplies/:eamapply?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamapply.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-info-view/eamapply-info-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamasset.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-grid-view/eamasset-grid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamasset.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-grid-view/eamasset-grid-view.vue'),
                },
                {
                    path: 'eamsparepartsgroups/:eamsparepartsgroup?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamsparepartsgroup.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamsparepartsgroups', parameterName: 'eamsparepartsgroup' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamspare-parts-group-edit-view/eamspare-parts-group-edit-view.vue'),
                },
                {
                    path: 'eammonitorpoints/:eammonitorpoint?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.eammonitorpoint.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eammonitorpoints', parameterName: 'eammonitorpoint' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eammonitor-point-pickup-view/eammonitor-point-pickup-view.vue'),
                },
                {
                    path: 'eamapplytypes/:eamapplytype?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.eamapplytype.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamapplytypes', parameterName: 'eamapplytype' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-type-pickup-view/eamapply-type-pickup-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamplans/:eamplan?/eamworkorders/:eamworkorder?/childwogridview/:childwogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.childwogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'childwogridview', parameterName: 'childwogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-child-wogrid-view/eamwork-order-child-wogrid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamapplies/:eamapply?/eamworkorders/:eamworkorder?/childwogridview/:childwogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.childwogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'childwogridview', parameterName: 'childwogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-child-wogrid-view/eamwork-order-child-wogrid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamplans/:eamplan?/eamworkorders/:eamworkorder?/childwogridview/:childwogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.childwogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'childwogridview', parameterName: 'childwogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-child-wogrid-view/eamwork-order-child-wogrid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamworkorders/:eamworkorder?/childwogridview/:childwogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.childwogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'childwogridview', parameterName: 'childwogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-child-wogrid-view/eamwork-order-child-wogrid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamapplies/:eamapply?/eamworkorders/:eamworkorder?/childwogridview/:childwogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.childwogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'childwogridview', parameterName: 'childwogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-child-wogrid-view/eamwork-order-child-wogrid-view.vue'),
                },
                {
                    path: 'eamplans/:eamplan?/eamworkorders/:eamworkorder?/childwogridview/:childwogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.childwogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'childwogridview', parameterName: 'childwogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-child-wogrid-view/eamwork-order-child-wogrid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamworkorders/:eamworkorder?/childwogridview/:childwogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.childwogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'childwogridview', parameterName: 'childwogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-child-wogrid-view/eamwork-order-child-wogrid-view.vue'),
                },
                {
                    path: 'eamapplies/:eamapply?/eamworkorders/:eamworkorder?/childwogridview/:childwogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.childwogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'childwogridview', parameterName: 'childwogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-child-wogrid-view/eamwork-order-child-wogrid-view.vue'),
                },
                {
                    path: 'eamworkorders/:eamworkorder?/childwogridview/:childwogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.childwogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'childwogridview', parameterName: 'childwogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-child-wogrid-view/eamwork-order-child-wogrid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamplans/:eamplan?/eamworkorders/:eamworkorder?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-info-main-view/eamwork-order-info-main-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamapplies/:eamapply?/eamworkorders/:eamworkorder?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-info-main-view/eamwork-order-info-main-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamplans/:eamplan?/eamworkorders/:eamworkorder?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-info-main-view/eamwork-order-info-main-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamworkorders/:eamworkorder?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-info-main-view/eamwork-order-info-main-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamapplies/:eamapply?/eamworkorders/:eamworkorder?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-info-main-view/eamwork-order-info-main-view.vue'),
                },
                {
                    path: 'eamplans/:eamplan?/eamworkorders/:eamworkorder?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-info-main-view/eamwork-order-info-main-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamworkorders/:eamworkorder?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-info-main-view/eamwork-order-info-main-view.vue'),
                },
                {
                    path: 'eamapplies/:eamapply?/eamworkorders/:eamworkorder?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-info-main-view/eamwork-order-info-main-view.vue'),
                },
                {
                    path: 'eamworkorders/:eamworkorder?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-info-main-view/eamwork-order-info-main-view.vue'),
                },
                {
                    path: 'eamsparepartsgroups/:eamsparepartsgroup?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.eamsparepartsgroup.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamsparepartsgroups', parameterName: 'eamsparepartsgroup' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamspare-parts-group-pickup-view/eamspare-parts-group-pickup-view.vue'),
                },
                {
                    path: 'eamassetstates/:eamassetstate?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.eamassetstate.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassetstates', parameterName: 'eamassetstate' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-state-pickup-view/eamasset-state-pickup-view.vue'),
                },
                {
                    path: 'eamassetstates/:eamassetstate?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamassetstate.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassetstates', parameterName: 'eamassetstate' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-state-grid-view/eamasset-state-grid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamplans/:eamplan?/quickcreateview/:quickcreateview?',
                    meta: {
                        caption: 'entities.eamplan.views.quickcreateview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'quickcreateview', parameterName: 'quickcreateview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-quick-create-view/eamplan-quick-create-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamplans/:eamplan?/quickcreateview/:quickcreateview?',
                    meta: {
                        caption: 'entities.eamplan.views.quickcreateview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'quickcreateview', parameterName: 'quickcreateview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-quick-create-view/eamplan-quick-create-view.vue'),
                },
                {
                    path: 'eamplans/:eamplan?/quickcreateview/:quickcreateview?',
                    meta: {
                        caption: 'entities.eamplan.views.quickcreateview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'quickcreateview', parameterName: 'quickcreateview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-quick-create-view/eamplan-quick-create-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamplans/:eamplan?/eamworkorders/:eamworkorder?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-grid-view/eamwork-order-grid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamapplies/:eamapply?/eamworkorders/:eamworkorder?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-grid-view/eamwork-order-grid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamplans/:eamplan?/eamworkorders/:eamworkorder?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-grid-view/eamwork-order-grid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamworkorders/:eamworkorder?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-grid-view/eamwork-order-grid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamapplies/:eamapply?/eamworkorders/:eamworkorder?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-grid-view/eamwork-order-grid-view.vue'),
                },
                {
                    path: 'eamplans/:eamplan?/eamworkorders/:eamworkorder?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-grid-view/eamwork-order-grid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamworkorders/:eamworkorder?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-grid-view/eamwork-order-grid-view.vue'),
                },
                {
                    path: 'eamapplies/:eamapply?/eamworkorders/:eamworkorder?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-grid-view/eamwork-order-grid-view.vue'),
                },
                {
                    path: 'eamworkorders/:eamworkorder?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-grid-view/eamwork-order-grid-view.vue'),
                },
                {
                    path: 'eamassetstatemodels/:eamassetstatemodel?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamassetstatemodel.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassetstatemodels', parameterName: 'eamassetstatemodel' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-state-model-grid-view/eamasset-state-model-grid-view.vue'),
                },
                {
                    path: 'eamwotypes/:eamwotype?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamwotype.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamwotypes', parameterName: 'eamwotype' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwotype-grid-view/eamwotype-grid-view.vue'),
                },
                {
                    path: 'eamdocumenttypes/:eamdocumenttype?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.eamdocumenttype.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamdocumenttypes', parameterName: 'eamdocumenttype' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamdocument-type-pickup-view/eamdocument-type-pickup-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/locationassetgridview/:locationassetgridview?',
                    meta: {
                        caption: 'entities.eamasset.views.locationassetgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'locationassetgridview', parameterName: 'locationassetgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-location-asset-grid-view/eamasset-location-asset-grid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/locationassetgridview/:locationassetgridview?',
                    meta: {
                        caption: 'entities.eamasset.views.locationassetgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'locationassetgridview', parameterName: 'locationassetgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-location-asset-grid-view/eamasset-location-asset-grid-view.vue'),
                },
                {
                    path: 'eamsparepartsgroups/:eamsparepartsgroup?/eamassetpartsgroups/:eamassetpartsgroup?/partsassetgridview/:partsassetgridview?',
                    meta: {
                        caption: 'entities.eamassetpartsgroup.views.partsassetgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamsparepartsgroups', parameterName: 'eamsparepartsgroup' },
                            { pathName: 'eamassetpartsgroups', parameterName: 'eamassetpartsgroup' },
                            { pathName: 'partsassetgridview', parameterName: 'partsassetgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-parts-group-parts-asset-grid-view/eamasset-parts-group-parts-asset-grid-view.vue'),
                },
                {
                    path: 'eamassettypes/:eamassettype?/eamassetpartsgroups/:eamassetpartsgroup?/partsassetgridview/:partsassetgridview?',
                    meta: {
                        caption: 'entities.eamassetpartsgroup.views.partsassetgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassettypes', parameterName: 'eamassettype' },
                            { pathName: 'eamassetpartsgroups', parameterName: 'eamassetpartsgroup' },
                            { pathName: 'partsassetgridview', parameterName: 'partsassetgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-parts-group-parts-asset-grid-view/eamasset-parts-group-parts-asset-grid-view.vue'),
                },
                {
                    path: 'eamassetpartsgroups/:eamassetpartsgroup?/partsassetgridview/:partsassetgridview?',
                    meta: {
                        caption: 'entities.eamassetpartsgroup.views.partsassetgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassetpartsgroups', parameterName: 'eamassetpartsgroup' },
                            { pathName: 'partsassetgridview', parameterName: 'partsassetgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-parts-group-parts-asset-grid-view/eamasset-parts-group-parts-asset-grid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/infoview/:infoview?',
                    meta: {
                        caption: 'entities.eamlocation.views.infoview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'infoview', parameterName: 'infoview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-info-view/eamlocation-info-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamplans/:eamplan?/assetplangridview/:assetplangridview?',
                    meta: {
                        caption: 'entities.eamplan.views.assetplangridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'assetplangridview', parameterName: 'assetplangridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-asset-plan-grid-view/eamplan-asset-plan-grid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamplans/:eamplan?/assetplangridview/:assetplangridview?',
                    meta: {
                        caption: 'entities.eamplan.views.assetplangridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'assetplangridview', parameterName: 'assetplangridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-asset-plan-grid-view/eamplan-asset-plan-grid-view.vue'),
                },
                {
                    path: 'eamplans/:eamplan?/assetplangridview/:assetplangridview?',
                    meta: {
                        caption: 'entities.eamplan.views.assetplangridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'assetplangridview', parameterName: 'assetplangridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-asset-plan-grid-view/eamplan-asset-plan-grid-view.vue'),
                },
                {
                    path: 'eamassettypes/:eamassettype?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamassettype.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassettypes', parameterName: 'eamassettype' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-type-edit-view/eamasset-type-edit-view.vue'),
                },
                {
                    path: 'eamassettypes/:eamassettype?/eamdocuments/:eamdocument?/assettypedocgridview/:assettypedocgridview?',
                    meta: {
                        caption: 'entities.eamdocument.views.assettypedocgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassettypes', parameterName: 'eamassettype' },
                            { pathName: 'eamdocuments', parameterName: 'eamdocument' },
                            { pathName: 'assettypedocgridview', parameterName: 'assettypedocgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamdocument-asset-type-doc-grid-view/eamdocument-asset-type-doc-grid-view.vue'),
                },
                {
                    path: 'eamdocuments/:eamdocument?/assettypedocgridview/:assettypedocgridview?',
                    meta: {
                        caption: 'entities.eamdocument.views.assettypedocgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamdocuments', parameterName: 'eamdocument' },
                            { pathName: 'assettypedocgridview', parameterName: 'assettypedocgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamdocument-asset-type-doc-grid-view/eamdocument-asset-type-doc-grid-view.vue'),
                },
                {
                    path: 'eamlocationstates/:eamlocationstate?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamlocationstate.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocationstates', parameterName: 'eamlocationstate' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-state-edit-view/eamlocation-state-edit-view.vue'),
                },
                {
                    path: 'eamsparepartsgroups/:eamsparepartsgroup?/eamassetpartsgroups/:eamassetpartsgroup?/assetpartsgridview/:assetpartsgridview?',
                    meta: {
                        caption: 'entities.eamassetpartsgroup.views.assetpartsgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamsparepartsgroups', parameterName: 'eamsparepartsgroup' },
                            { pathName: 'eamassetpartsgroups', parameterName: 'eamassetpartsgroup' },
                            { pathName: 'assetpartsgridview', parameterName: 'assetpartsgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-parts-group-asset-parts-grid-view/eamasset-parts-group-asset-parts-grid-view.vue'),
                },
                {
                    path: 'eamassettypes/:eamassettype?/eamassetpartsgroups/:eamassetpartsgroup?/assetpartsgridview/:assetpartsgridview?',
                    meta: {
                        caption: 'entities.eamassetpartsgroup.views.assetpartsgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassettypes', parameterName: 'eamassettype' },
                            { pathName: 'eamassetpartsgroups', parameterName: 'eamassetpartsgroup' },
                            { pathName: 'assetpartsgridview', parameterName: 'assetpartsgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-parts-group-asset-parts-grid-view/eamasset-parts-group-asset-parts-grid-view.vue'),
                },
                {
                    path: 'eamassetpartsgroups/:eamassetpartsgroup?/assetpartsgridview/:assetpartsgridview?',
                    meta: {
                        caption: 'entities.eamassetpartsgroup.views.assetpartsgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassetpartsgroups', parameterName: 'eamassetpartsgroup' },
                            { pathName: 'assetpartsgridview', parameterName: 'assetpartsgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-parts-group-asset-parts-grid-view/eamasset-parts-group-asset-parts-grid-view.vue'),
                },
                {
                    path: 'eamlocationstatemodels/:eamlocationstatemodel?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamlocationstatemodel.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocationstatemodels', parameterName: 'eamlocationstatemodel' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-state-model-edit-view/eamlocation-state-model-edit-view.vue'),
                },
                {
                    path: 'eamassetstatemodels/:eamassetstatemodel?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.eamassetstatemodel.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassetstatemodels', parameterName: 'eamassetstatemodel' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-state-model-pickup-view/eamasset-state-model-pickup-view.vue'),
                },
                {
                    path: 'eamlocationstatemodellines/:eamlocationstatemodelline?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamlocationstatemodelline.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocationstatemodellines', parameterName: 'eamlocationstatemodelline' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-state-model-line-edit-view/eamlocation-state-model-line-edit-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.eamasset.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-pickup-grid-view/eamasset-pickup-grid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.eamasset.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-pickup-grid-view/eamasset-pickup-grid-view.vue'),
                },
                {
                    path: 'eamlocationstates/:eamlocationstate?/listexpview/:listexpview?',
                    meta: {
                        caption: 'entities.eamlocationstate.views.listexpview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocationstates', parameterName: 'eamlocationstate' },
                            { pathName: 'listexpview', parameterName: 'listexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-state-list-exp-view/eamlocation-state-list-exp-view.vue'),
                },
                {
                    path: 'eamlocationtypes/:eamlocationtype?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamlocationtype.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocationtypes', parameterName: 'eamlocationtype' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-type-edit-view/eamlocation-type-edit-view.vue'),
                },
                {
                    path: 'eamsparepartsgroups/:eamsparepartsgroup?/info_mainview/:info_mainview?',
                    meta: {
                        caption: 'entities.eamsparepartsgroup.views.info_mainview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamsparepartsgroups', parameterName: 'eamsparepartsgroup' },
                            { pathName: 'info_mainview', parameterName: 'info_mainview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamspare-parts-group-info-main-view/eamspare-parts-group-info-main-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/summaryview/:summaryview?',
                    meta: {
                        caption: 'entities.eamlocation.views.summaryview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'summaryview', parameterName: 'summaryview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/location/eamlocation-summary-view/eamlocation-summary-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/quickcreateview/:quickcreateview?',
                    meta: {
                        caption: 'entities.eamasset.views.quickcreateview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'quickcreateview', parameterName: 'quickcreateview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-quick-create-view/eamasset-quick-create-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/quickcreateview/:quickcreateview?',
                    meta: {
                        caption: 'entities.eamasset.views.quickcreateview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'quickcreateview', parameterName: 'quickcreateview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-quick-create-view/eamasset-quick-create-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.eamasset.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-pickup-view/eamasset-pickup-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.eamasset.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamasset-pickup-view/eamasset-pickup-view.vue'),
                },
                {
                    path: 'eamapplytypes/:eamapplytype?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.eamapplytype.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamapplytypes', parameterName: 'eamapplytype' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/apply/eamapply-type-grid-view/eamapply-type-grid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamplans/:eamplan?/eamworkorders/:eamworkorder?/assetwogridview/:assetwogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.assetwogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'assetwogridview', parameterName: 'assetwogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-asset-wogrid-view/eamwork-order-asset-wogrid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamapplies/:eamapply?/eamworkorders/:eamworkorder?/assetwogridview/:assetwogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.assetwogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'assetwogridview', parameterName: 'assetwogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-asset-wogrid-view/eamwork-order-asset-wogrid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamplans/:eamplan?/eamworkorders/:eamworkorder?/assetwogridview/:assetwogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.assetwogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'assetwogridview', parameterName: 'assetwogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-asset-wogrid-view/eamwork-order-asset-wogrid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamworkorders/:eamworkorder?/assetwogridview/:assetwogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.assetwogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'assetwogridview', parameterName: 'assetwogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-asset-wogrid-view/eamwork-order-asset-wogrid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamapplies/:eamapply?/eamworkorders/:eamworkorder?/assetwogridview/:assetwogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.assetwogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'assetwogridview', parameterName: 'assetwogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-asset-wogrid-view/eamwork-order-asset-wogrid-view.vue'),
                },
                {
                    path: 'eamplans/:eamplan?/eamworkorders/:eamworkorder?/assetwogridview/:assetwogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.assetwogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'assetwogridview', parameterName: 'assetwogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-asset-wogrid-view/eamwork-order-asset-wogrid-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamworkorders/:eamworkorder?/assetwogridview/:assetwogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.assetwogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'assetwogridview', parameterName: 'assetwogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-asset-wogrid-view/eamwork-order-asset-wogrid-view.vue'),
                },
                {
                    path: 'eamapplies/:eamapply?/eamworkorders/:eamworkorder?/assetwogridview/:assetwogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.assetwogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'assetwogridview', parameterName: 'assetwogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-asset-wogrid-view/eamwork-order-asset-wogrid-view.vue'),
                },
                {
                    path: 'eamworkorders/:eamworkorder?/assetwogridview/:assetwogridview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.assetwogridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'assetwogridview', parameterName: 'assetwogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-asset-wogrid-view/eamwork-order-asset-wogrid-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamplans/:eamplan?/eamworkorders/:eamworkorder?/quickcreateview/:quickcreateview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.quickcreateview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'quickcreateview', parameterName: 'quickcreateview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-quick-create-view/eamwork-order-quick-create-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamapplies/:eamapply?/eamworkorders/:eamworkorder?/quickcreateview/:quickcreateview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.quickcreateview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'quickcreateview', parameterName: 'quickcreateview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-quick-create-view/eamwork-order-quick-create-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamplans/:eamplan?/eamworkorders/:eamworkorder?/quickcreateview/:quickcreateview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.quickcreateview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'quickcreateview', parameterName: 'quickcreateview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-quick-create-view/eamwork-order-quick-create-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamworkorders/:eamworkorder?/quickcreateview/:quickcreateview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.quickcreateview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'quickcreateview', parameterName: 'quickcreateview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-quick-create-view/eamwork-order-quick-create-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamapplies/:eamapply?/eamworkorders/:eamworkorder?/quickcreateview/:quickcreateview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.quickcreateview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'quickcreateview', parameterName: 'quickcreateview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-quick-create-view/eamwork-order-quick-create-view.vue'),
                },
                {
                    path: 'eamplans/:eamplan?/eamworkorders/:eamworkorder?/quickcreateview/:quickcreateview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.quickcreateview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'quickcreateview', parameterName: 'quickcreateview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-quick-create-view/eamwork-order-quick-create-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamworkorders/:eamworkorder?/quickcreateview/:quickcreateview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.quickcreateview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'quickcreateview', parameterName: 'quickcreateview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-quick-create-view/eamwork-order-quick-create-view.vue'),
                },
                {
                    path: 'eamapplies/:eamapply?/eamworkorders/:eamworkorder?/quickcreateview/:quickcreateview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.quickcreateview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamapplies', parameterName: 'eamapply' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'quickcreateview', parameterName: 'quickcreateview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-quick-create-view/eamwork-order-quick-create-view.vue'),
                },
                {
                    path: 'eamworkorders/:eamworkorder?/quickcreateview/:quickcreateview?',
                    meta: {
                        caption: 'entities.eamworkorder.views.quickcreateview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamworkorders', parameterName: 'eamworkorder' },
                            { pathName: 'quickcreateview', parameterName: 'quickcreateview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/work-order/eamwork-order-quick-create-view/eamwork-order-quick-create-view.vue'),
                },
                {
                    path: 'eamlocations/:eamlocation?/eamassets/:eamasset?/eamplans/:eamplan?/summaryview/:summaryview?',
                    meta: {
                        caption: 'entities.eamplan.views.summaryview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamlocations', parameterName: 'eamlocation' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'summaryview', parameterName: 'summaryview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-summary-view/eamplan-summary-view.vue'),
                },
                {
                    path: 'eamassets/:eamasset?/eamplans/:eamplan?/summaryview/:summaryview?',
                    meta: {
                        caption: 'entities.eamplan.views.summaryview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamassets', parameterName: 'eamasset' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'summaryview', parameterName: 'summaryview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-summary-view/eamplan-summary-view.vue'),
                },
                {
                    path: 'eamplans/:eamplan?/summaryview/:summaryview?',
                    meta: {
                        caption: 'entities.eamplan.views.summaryview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamplans', parameterName: 'eamplan' },
                            { pathName: 'summaryview', parameterName: 'summaryview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/plan/eamplan-summary-view/eamplan-summary-view.vue'),
                },
                {
                    path: 'eamsparepartsgroups/:eamsparepartsgroup?/eamsparepartspros/:eamsparepartspro?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamsparepartspro.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamsparepartsgroups', parameterName: 'eamsparepartsgroup' },
                            { pathName: 'eamsparepartspros', parameterName: 'eamsparepartspro' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamspare-parts-proedit-view/eamspare-parts-proedit-view.vue'),
                },
                {
                    path: 'eamsparepartspros/:eamsparepartspro?/editview/:editview?',
                    meta: {
                        caption: 'entities.eamsparepartspro.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'appindexview', parameterName: 'appindexview' },
                            { pathName: 'eamsparepartspros', parameterName: 'eamsparepartspro' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/asset/eamspare-parts-proedit-view/eamspare-parts-proedit-view.vue'),
                },
            ...indexRoutes,
            ],
        },
        ...globalRoutes,
        {
            path: '/login/:login?',
            name: 'login',
            meta: {  
                caption: '登录',
                viewType: 'login',
                requireAuth: false,
                ignoreAddPage: true,
            },
            beforeEnter: (to: any, from: any, next: any) => {
                appService.navHistory.reset();
                next();
            },
            component: () => import('@components/login/login'),
        },
        {
            path: '/404',
            component: () => import('@components/404/404.vue')
        },
        {
            path: '/500',
            component: () => import('@components/500/500.vue')
        },
        {
            path: '*',
            redirect: 'appindexview'
        }
    ]
});

router.beforeEach((to: any, from: any, next: any) => {
    if (to.meta && !to.meta.ignoreAddPage) {
        appService.navHistory.add(to);
    }
    next();
});

export default router;